export * as performance from './src/performance';

export const isIOS = () => {
    return /(iPhone|iPad|iPod|iOS)/i.test(navigator.userAgent)
}
// 判断输入字符串是否为空
export const isNullString = str => str === ''
// 判断输入字符串是否全为汉字
export const isChCn = str => /^[\u4E00-\u9FA5]+$/.test(str)
// 判断字符串是否全是数字
export const isNumber = str => /^[0-9]+$/.test(str)
// 判断身份证号码格式是否正确
export const isIdNumberOk = str => /^(^[1-9]\d{7}((0\d)|(1[0-2]))(([0-2]\d)|3[0-1])\d{3}$)|(^[1-9]\d{5}[1-9]\d{3}((0\d)|(1[0-2]))(([0-2]\d)|3[0-1])((\d{4})|\d{3}[Xx])$)$/.test(str)
// 判断数字是否超过范围
export const isNumInRange = (val, min, max) => val >= min && val <= max
// 判断是否是手机号
export const isPhoneNumber = str => /^[1][3-8][0-9]{9}$/.test(str)

// 通过一个虚拟的a标签进行跳转
export const jumpViaA = url => {
    let A = window.document.createElement('a')
    A.setAttribute('target', '_blank')
    A.setAttribute('href', url)
    let e = document.createEvent('MouseEvents')
    e.initEvent('click', true, true)
    A.dispatchEvent(e)
}
// 打印cookie
export const printCookie = () => {
    toastedShow('cookie: ' + window.document.cookie)
    console.log('cookie: ' + window.document.cookie)
}

// 获取url上的参数
export const getQueryParam = url => {
    url = url || window.location.href
    let theRequest = {}
    if (url.indexOf("?") !== -1) {
        let str = url.split('?')[1];
        let strs = str.split("&");
        for (let i = 0; i < strs.length; i++) {
            // theRequest[strs[i].split("=")[0]] = unescape(strs[i].split("=")[1]);
            theRequest[strs[i].split("=")[0]] = decodeURIComponent(strs[i].split("=")[1]);
        }
    }
    return theRequest;
}

// 修复键盘弹出导致布局混乱bug
export const KeyboardPop = function (normalCb, popCb) {
    this.h = 0
    // 创建对象时，可能页面视口没有初始化完成，延迟100ms获取视口高度
    setTimeout(() => {
        this.h = window.innerHeight
    }, 100)
    
    // 监听resize事件
    // 如果当前视口高度小于页面初始化，说明键盘弹起，调用弹起状态回调 popb
    // 否则，认为视口没有变化，调用正常状态回调 normalCb
    window.onresize = () => {
        if (window.innerHeight < this.h) {
            popCb()
        } else {
            normalCb()
        }
    }
}

export const formatDate = val => {
    let d = new Date(val)
    let year = d.getFullYear()
    let month = (d.getMonth() + 101 + '').substring(1)
    let date = (d.getDate() + 100 + '').substring(1)
    return year + '年' + month + '月' + date + '日'
}

/**
 * 
 * @param {String} v1 版本号，支持 xxx-v3.2.1
 * @param {String} v2 版本号，同上 xxx-v3.2.0
 * @returns {String} 返回更大的 版本号 如 v3.2.1
 * @description 这个方法接受两个版本号，返回更大的那个版本号
 */
export const compareVersion = (v1, v2) => {
    let _v1 = v1.split(/-|v/);
    let _v2 = v2.split(/-|v/);
    _v1 = _v1[_v1.length-1]
    _v2 = _v2[_v2.length-1]
    if(_v1 === '') return _v2
    if(_v2 === '') return _v1
    let major1 = _v1.split('.')[0] - 0
    let minor1 = _v1.split('.')[1] - 0
    let patch1 = _v1.split('.')[2] - 0
    let major2 = _v2.split('.')[0] - 0
    let minor2 = _v2.split('.')[1] - 0
    let patch2 = _v2.split('.')[2] - 0
    if(major1 > major2) {
      return _v1;
    } else if(minor1 > minor2) {
      return _v1
    } else if(patch1 > patch2) {
      return _v1
    } else {
      return _v2
    }
  }